==> ejc-settlementmanage-impl-3.0.0-20221022.042622-79-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookStatementDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-收入明细表-工程量清单结算表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_statement")
public class SettlementBookStatementDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="listing_code")
    private java.lang.String listingCode; // 清单编码
    @TableField(value="units")
    private java.lang.String units; // 单位
    @TableField(value="quantities")
    private java.math.BigDecimal quantities; // 工程量
    @TableField(value="extax_unitprice")
    private java.math.BigDecimal extaxUnitprice; // 合同单价除税
    @TableField(value="intax_unitprice")
    private java.math.BigDecimal intaxUnitprice; // 合同单价含税
    @TableField(value="exsettlement_unitprice")
    private java.math.BigDecimal exsettlementUnitprice; // 结算除税单价
    @TableField(value="insettlement_unitprice")
    private java.math.BigDecimal insettlementUnitprice; // 结算含税单价
    @TableField(value="extax_addition")
    private java.math.BigDecimal extaxAddition; // 除税合价
    @TableField(value="intax_addition")
    private java.math.BigDecimal intaxAddition; // 含税合价
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="part_project_name")
    private java.lang.String partProjectName; // 分部分项工程名称
    @TableField(value="source")
    private java.lang.String source; // 来源
    @TableField(value="section")
    private String section; // 区段
    @TableField(value="subitem_desc")
    private String subitemDesc; // 子目特征描述
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }

    public BigDecimal getQuantities() {
        return quantities;
    }

    public void setQuantities(BigDecimal quantities) {
        this.quantities = quantities;
    }

    public BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    public void setExtaxUnitprice(BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 结算除税单价
     */
    public java.math.BigDecimal getExsettlementUnitprice() {
        return exsettlementUnitprice;
    }

    /**
     * 结算除税单价
     */
    public void setExsettlementUnitprice(java.math.BigDecimal exsettlementUnitprice) {
        this.exsettlementUnitprice = exsettlementUnitprice;
    }
    /**
     * 结算含税单价
     */
    public java.math.BigDecimal getInsettlementUnitprice() {
        return insettlementUnitprice;
    }

    /**
     * 结算含税单价
     */
    public void setInsettlementUnitprice(java.math.BigDecimal insettlementUnitprice) {
        this.insettlementUnitprice = insettlementUnitprice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExtaxAddition() {
        return extaxAddition;
    }

    /**
     * 除税合价
     */
    public void setExtaxAddition(java.math.BigDecimal extaxAddition) {
        this.extaxAddition = extaxAddition;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIntaxAddition() {
        return intaxAddition;
    }

    /**
     * 含税合价
     */
    public void setIntaxAddition(java.math.BigDecimal intaxAddition) {
        this.intaxAddition = intaxAddition;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getPartProjectName() {
        return partProjectName;
    }

    public void setPartProjectName(String partProjectName) {
        this.partProjectName = partProjectName;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20221031.103951-96-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookStatementDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-收入明细表-工程量清单结算表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_statement")
public class SettlementBookStatementDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="listing_code")
    private java.lang.String listingCode; // 清单编码
    @TableField(value="units")
    private java.lang.String units; // 单位
    @TableField(value="quantities")
    private java.math.BigDecimal quantities; // 工程量
    @TableField(value="extax_unitprice")
    private java.math.BigDecimal extaxUnitprice; // 合同单价除税
    @TableField(value="intax_unitprice")
    private java.math.BigDecimal intaxUnitprice; // 合同单价含税
    @TableField(value="exsettlement_unitprice")
    private java.math.BigDecimal exsettlementUnitprice; // 结算除税单价
    @TableField(value="insettlement_unitprice")
    private java.math.BigDecimal insettlementUnitprice; // 结算含税单价
    @TableField(value="extax_addition")
    private java.math.BigDecimal extaxAddition; // 除税合价
    @TableField(value="intax_addition")
    private java.math.BigDecimal intaxAddition; // 含税合价
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="part_project_name")
    private java.lang.String partProjectName; // 分部分项工程名称
    @TableField(value="source")
    private java.lang.String source; // 来源
    @TableField(value="section")
    private String section; // 区段
    @TableField(value="subitem_desc")
    private String subitemDesc; // 子目特征描述

    @TableField(value="accruing_amounts_notax")
    private java.math.BigDecimal accruingAmountsNotax;  //累计报量金额(除税)
    @TableField(value="accruing_amounts_tax")
    private java.math.BigDecimal accruingAmountsTax;  //累计报量金额(含税)
    @TableField(value="this_amounts_notax")
    private java.math.BigDecimal thisAmountsNotax;  //本次报量金额(除税)
    @TableField(value="this_amounts_tax")
    private java.math.BigDecimal thisAmountsTax;  //本次报量金额(含税)

    @TableField(value="cumulative_engineering_quantity")
    private java.math.BigDecimal cumulativeEngineeringQuantity;  //累计报量工程

    @TableField(value="this_engineering_quantity")
    private java.math.BigDecimal thisEngineeringQuantity;  //本期报量工程
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }

    public BigDecimal getQuantities() {
        return quantities;
    }

    public void setQuantities(BigDecimal quantities) {
        this.quantities = quantities;
    }

    public BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    public void setExtaxUnitprice(BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 结算除税单价
     */
    public java.math.BigDecimal getExsettlementUnitprice() {
        return exsettlementUnitprice;
    }

    /**
     * 结算除税单价
     */
    public void setExsettlementUnitprice(java.math.BigDecimal exsettlementUnitprice) {
        this.exsettlementUnitprice = exsettlementUnitprice;
    }
    /**
     * 结算含税单价
     */
    public java.math.BigDecimal getInsettlementUnitprice() {
        return insettlementUnitprice;
    }

    /**
     * 结算含税单价
     */
    public void setInsettlementUnitprice(java.math.BigDecimal insettlementUnitprice) {
        this.insettlementUnitprice = insettlementUnitprice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExtaxAddition() {
        return extaxAddition;
    }

    /**
     * 除税合价
     */
    public void setExtaxAddition(java.math.BigDecimal extaxAddition) {
        this.extaxAddition = extaxAddition;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIntaxAddition() {
        return intaxAddition;
    }

    /**
     * 含税合价
     */
    public void setIntaxAddition(java.math.BigDecimal intaxAddition) {
        this.intaxAddition = intaxAddition;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getPartProjectName() {
        return partProjectName;
    }

    public void setPartProjectName(String partProjectName) {
        this.partProjectName = partProjectName;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }

    public BigDecimal getAccruingAmountsNotax() {
        return accruingAmountsNotax;
    }

    public void setAccruingAmountsNotax(BigDecimal accruingAmountsNotax) {
        this.accruingAmountsNotax = accruingAmountsNotax;
    }

    public BigDecimal getAccruingAmountsTax() {
        return accruingAmountsTax;
    }

    public void setAccruingAmountsTax(BigDecimal accruingAmountsTax) {
        this.accruingAmountsTax = accruingAmountsTax;
    }

    public BigDecimal getThisAmountsNotax() {
        return thisAmountsNotax;
    }

    public void setThisAmountsNotax(BigDecimal thisAmountsNotax) {
        this.thisAmountsNotax = thisAmountsNotax;
    }

    public BigDecimal getThisAmountsTax() {
        return thisAmountsTax;
    }

    public void setThisAmountsTax(BigDecimal thisAmountsTax) {
        this.thisAmountsTax = thisAmountsTax;
    }

    public BigDecimal getCumulativeEngineeringQuantity() {
        return cumulativeEngineeringQuantity;
    }

    public void setCumulativeEngineeringQuantity(BigDecimal cumulativeEngineeringQuantity) {
        this.cumulativeEngineeringQuantity = cumulativeEngineeringQuantity;
    }

    public BigDecimal getThisEngineeringQuantity() {
        return thisEngineeringQuantity;
    }

    public void setThisEngineeringQuantity(BigDecimal thisEngineeringQuantity) {
        this.thisEngineeringQuantity = thisEngineeringQuantity;
    }
}
